# This module should calculate verification metrics at any time of the workflow
# It should implement different verification metrics:
# - FRPSS and RPSS
# - FCRPSS abd CRPSS
# - enscorr
# - bias
# - reliability diagram
# - ask Carlos which decadal metrics he is currently using

## Which parameter are required?
if (!("obs" %in% ls()) || is.null(obs)) {
  error(logger,
        "There is no object 'obs' in the global environment or it is NULL")
}
if (stream == "fcst" && (!("fcst" %in% ls()) || is.null(fcst))) {
  error(logger,
        "There is no object 'fcst' in the global environment or it is NULL")
}
if (!("hcst" %in% ls()) || is.null(hcst)) {
  error(logger,
        "There is no object 'hcst' in the global environment or it is NULL")
}
if (!("metric" %in% ls()) || is.null(metric)) {
  warn(logger,
       "Verification metric not found and it is set as 'EnsCorr'.")
  metric <- 'EnsCorr'
}
if (metric %in% c('FRPSS', 'RPSS')) {
  metric_fun <- "veriApply"
  metric_method <- "FairRpss"
} else if (metric %in% c("FCRPSS", "CRPSS")) {
  metric_fun <- "veriApply"
} else if (metric %in% c("EnsCorr", "EnsCor")) {
  metric_fun <- "veriApply"
  metric_method <- "EnsCorr"
#...
} else {
  error(logger, "Unknown verification metric defined in the recipe.")
  metric_fun <- 'NotFound'
}
info(logger, paste("#-------------------------- ", "\n",
                   " running Skill module ", "\n",
                   " it can call ", metric_fun ))
